import React from "react";
import { Table, InternalLink, EllipsisText } from "@ess-ics/ce-ui-common";
import { HostStatusIcon } from "./HostIcons";

const columns = [
  {
    field: "bulb",
    headerName: "Status",
    flex: 0,
    headerAlign: "center",
    align: "center"
  },
  { field: "hostName", headerName: "Host" },
  { field: "description", headerName: "Description" },
  { field: "network", headerName: "Network" },
  { field: "scope", headerName: "Network scope" }
];

export function createRow(hostContainer) {
  const host = hostContainer.netBoxHost;
  return {
    id: host.hostId,
    bulb: <HostStatusIcon host={hostContainer} />,
    hostName: (
      <InternalLink
        to={`/hosts/${host.hostId}`}
        label={`Host details, ${host.name}`}
        width="100%"
      >
        <EllipsisText>{host.name}</EllipsisText>
      </InternalLink>
    ),
    host: host,
    description: <EllipsisText>{host.description}</EllipsisText>,
    network: <EllipsisText>{host.network}</EllipsisText>,
    scope: <EllipsisText>{host.scope}</EllipsisText>,
    discrepancy: hostContainer.alertSeverity === "WARNING",
    inconsistentState: hostContainer.alertSeverity === "ERROR",
    shortenLongData: true,
    iocNotDeployed: !hostContainer.iocDeployed
  };
}

export function HostTable({ hosts, pagination, onPage, loading }) {
  return (
    <Table
      columns={columns}
      rows={hosts.map((host) => createRow(host))}
      pagination={pagination}
      onPage={onPage}
      loading={loading}
      disableHover
    />
  );
}
